@@ -28,6 +28,9 @@ has 'persist_immediately' => ( is => 'ro', isa => 'HashRef', default => sub{{
 	destroy	=> \0
 }});
 
+# New option added in GitHub Issue #85
+has 'dedicated_add_form_enabled', is => 'ro', isa => 'Bool', default => 1;
+
 # use_add_form/use_edit_form: 'tab', 'window' or undef
 has 'use_add_form', is => 'ro', isa => 'Maybe[Str]', lazy => 1, default => undef;
 has 'use_edit_form', is => 'ro', isa => 'Maybe[Str]', lazy => 1, default => undef;
@@ -116,6 +119,9 @@ sub BUILD {}
 before 'BUILD' => sub { (shift)->DataStore2_BUILD };
 sub DataStore2_BUILD {
 	my $self = shift;
+  
+  # New for #85:
+  $self->apply_actions( add => 'dedicated_add_form' ) if ($self->dedicated_add_form_enabled);
 	
 	my $store_params = { 
 		record_pk 		=> $self->record_pk,
@@ -316,6 +322,18 @@ sub get_add_edit_form_items {
 		$field->{header} = $colname unless (defined $field->{header} and $field->{header} ne '');
 		$field->{fieldLabel} = $field->{header};
     $field->{anchor} = '-20';
+    
+    # ---- Moved from DataStorePlus JS (client-side):
+    # Important: autoDestroy must be false on the store or else store-driven
+    # components (i.e. combos) will be broken as soon as the form is closed 
+    # the first time
+    $field->{store}{autoDestroy} = \1 if ($field->{store});
+    
+    # Make sure that hidden fields that can't be changed don't 
+    # block validation of the form if they are empty and erroneously
+    # set with allowBlank: false (common-sense failsafe):
+    $field->{allowBlank} = \1 if (jstrue $field->{hidden});
+    # ----
 		
 		push @items, $field;
 	}
@@ -439,6 +457,37 @@ sub param_decodeIf {
 }
 
 
+# New for #85:
+sub dedicated_add_form {
+  my $self = shift;
+  die "Not allowed" unless $self->dedicated_add_form_enabled;
+  
+  my $c = $self->c;
+  my $content = $self->content;
+  
+  # Just in case custom add_form_url_params are configured, merge them into the current
+  # request params so they are available as they would be if called via Ajax...
+  my $afuParams = $self->get_extconfig_param('add_form_url_params') || {};
+  %{$c->req->params} = ( %{$c->req->params}, %$afuParams );
+  
+  my $fp = $self->get_add_form;
+  
+  my $btnCfg = ($self->get_extconfig_param('store_button_cnf')||{})->{add} || {};
+  
+  return $self->render_data({
+    xtype      => 'datastore-dedicated-add-form',
+    
+    source_cmp => $content,
+    formpanel  => $fp,
+    
+    tabTitle   => $btnCfg->{text}    || '(Add ...)',
+    tabIconCls => $btnCfg->{iconCls} || 'ra-icon-add'
+    
+  });
+}
+  
+
+
 #### --------------------- ####
 
 
